@@ -4,6 +4,7 @@ use std::io::BufReader;
 use tokio::process::Command;
 
 use gcloud_utils::cli::{Cli, Commands, GcpConfig};
+use gcloud_utils::gh::*;
 use gcloud_utils::iam::*;
 use gcloud_utils::run::*;
 
@@ -35,6 +36,12 @@ async fn main() {
             }
             _ => println!("no command!"),
         },
+        Commands::Gh { action } => match &*action {
+            "add-env" => {
+                process_setup_secret().await;
+            }
+            _ => println!("no command!"),
+        },
     }
 }
 
